==> iTop-3.0.3-10998.zip: web/dictionaries/ui/pages/preferences/en.dictionary.itop.preferences.php <==
<?php
/**
 * Copyright (C) 2013-2021 Combodo SARL
 *
 * This file is part of iTop.
 *
 * iTop is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * iTop is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 */

// Navigation menu
Dict::Add('EN US', 'English', 'English', array(
	'UI:Preferences:Title'                                             => 'Preferences',
	'UI:Preferences:UserInterface:Title'                               => 'User interface',
	'UI:Preferences:General:Title'                                     => 'General',
	'UI:Preferences:General:Theme'                                     => 'Theme',
	'UI:Preferences:General:Theme:DefaultThemeLabel'                   => '%1$s (default)',
	'UI:Preferences:Lists:Title'                                       => 'Lists',
	'UI:Preferences:RichText:Title'                                    => 'Rich text editor',
	'UI:Preferences:RichText:ToolbarState'                             => 'Toolbar default state',
	'UI:Preferences:RichText:ToolbarState:Expanded'                    => 'Expanded',
	'UI:Preferences:RichText:ToolbarState:Collapsed'                   => 'Collapsed',
	'UI:Preferences:ActivityPanel:Title'                               => 'Activity panel',
	'UI:Preferences:ActivityPanel:EntryFormOpened'                     => 'Entry form opened by default',
	'UI:Preferences:ActivityPanel:EntryFormOpened+'                    => 'Whether the entry form will be opened when displaying an object. If unchecked, you will still be able to open it by clicking the compose button',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Title'                => 'Application keyboard shortcuts',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Input:Hint'           => 'Type a keyboard shortcut',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Button:Tooltip'       => 'Record a keyboard shortcut',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Button:Reset'         => 'Reset',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Button:Reset:Tooltip' => 'Back to default keyboard shortcut',
	'UI:Preferences:Tabs:Title'                                        => 'Tabs',
	'UI:Preferences:Tabs:Layout:Label'                                 => 'Layout',
	'UI:Preferences:Tabs:Layout:Horizontal'                            => 'Horizontal',
	'UI:Preferences:Tabs:Layout:Vertical'                              => 'Vertical',
	'UI:Preferences:Tabs:Scrollable:Label'                             => 'Navigation',
	'UI:Preferences:Tabs:Scrollable:Classic'                           => 'Classic',
	'UI:Preferences:Tabs:Scrollable:Scrollable'                        => 'Scrollable',
	'UI:Preferences:ChooseAPlaceholder'                                => 'User placeholder image',
	'UI:Preferences:ChooseAPlaceholder+'                               => 'Choose a placeholder image that will be displayed if the contact linked to your user doesn\'t have one',
));

==> iTop-3.1.0-2-11973.zip: web/dictionaries/ui/pages/preferences/en.dictionary.itop.preferences.php <==
<?php
/**
 * Copyright (C) 2013-2023 Combodo SARL
 *
 * This file is part of iTop.
 *
 * iTop is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * iTop is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 */

// Navigation menu
Dict::Add('EN US', 'English', 'English', array(
	'UI:Preferences:Title'                                             => 'Preferences',
	'UI:Preferences:UserInterface:Title'                               => 'User interface',
	'UI:Preferences:General:Title'                                     => 'General',
	'UI:Preferences:General:Theme'                                     => 'Theme',
	'UI:Preferences:General:Theme:DefaultThemeLabel'                   => '%1$s (default)',
	'UI:Favorites:General:ShowSummaryCards'                            => 'Show summary cards',
	'UI:Favorites:General:ShowSummaryCards+'                           => 'When hovering an hyperlink targeting an object, display a short summary of the object, if available for that class',
	'UI:Preferences:Lists:Title'                                       => 'Lists',
	'UI:Preferences:RichText:Title'                                    => 'Rich text editor',
	'UI:Preferences:RichText:ToolbarState'                             => 'Toolbar default state',
	'UI:Preferences:RichText:ToolbarState:Expanded'                    => 'Expanded',
	'UI:Preferences:RichText:ToolbarState:Collapsed'                   => 'Collapsed',
	'UI:Preferences:ActivityPanel:Title'                               => 'Activity panel',
	'UI:Preferences:ActivityPanel:EntryFormOpened'                     => 'Entry form opened by default',
	'UI:Preferences:ActivityPanel:EntryFormOpened+'                    => 'Whether the entry form will be opened when displaying an object. If unchecked, you will still be able to open it by clicking the compose button',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Title'                => 'Application keyboard shortcuts',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Input:Hint'           => 'Type a keyboard shortcut',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Button:Tooltip'       => 'Record a keyboard shortcut',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Button:Reset'         => 'Reset',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Button:Reset:Tooltip' => 'Back to default keyboard shortcut',
	'UI:Preferences:Tabs:Title'                                        => 'Tabs',
	'UI:Preferences:Tabs:Layout:Label'                                 => 'Layout',
	'UI:Preferences:Tabs:Layout:Horizontal'                            => 'Horizontal',
	'UI:Preferences:Tabs:Layout:Vertical'                              => 'Vertical',
	'UI:Preferences:Tabs:Scrollable:Label'                             => 'Navigation',
	'UI:Preferences:Tabs:Scrollable:Classic'                           => 'Classic',
	'UI:Preferences:Tabs:Scrollable:Scrollable'                        => 'Scrollable',
	'UI:Preferences:ChooseAPlaceholder'                                => 'User placeholder image',
	'UI:Preferences:ChooseAPlaceholder+'                               => 'Choose a placeholder image that will be displayed if the contact linked to your user doesn\'t have one',
));
